@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # 
 # PyHoca is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -24,15 +24,17 @@ NSIS_SCRIPT_TEMPLATE = """
 
 !define VERSION {program_version}
 
+!define UNINSTALL_REGKEY    "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}"
+
 ;--------------------------------
 
 ; The name of the installer
 Name "{program_name}"
 
-; Sets the title bar text (although NSIS seems to append "Installer")
-Caption "{program_desc}"
+; Sets the title bar text
+Caption "{program_desc_short}"
 
-!define py2exeOutputDirectory '{output_dir}'
+!define distOutputDirectory '{output_dir}'
 
 ; The file to write
 OutFile "..\\{program_name}_${{VERSION}}_win32-setup.exe"
@@ -40,6 +42,10 @@ OutFile "..\\{program_name}_${{VERSION}}_win32-setup.exe"
 ; The default installation directory
 InstallDir $PROGRAMFILES\\{program_name}
 
+; NSIS 2.46 defaults to zlib. Setting this reduces the size of current
+; builds (which include no fonts for the X server) by about 27%
+SetCompressor /SOLID lzma
+
 ; Registry key to check for directory (so if you install again, it will 
 ; overwrite the old one automatically)
 InstallDirRegKey HKLM "Software\\{program_name}" "Install_Dir"
@@ -54,7 +60,7 @@ InstallDirRegKey HKLM "Software\\{program_name}" "Install_Dir"
 !include MUI2.nsh
 
 !insertmacro MULTIUSER_PAGE_INSTALLMODE
-!insertmacro MUI_PAGE_LICENSE LICENSE.txt
+!insertmacro MUI_PAGE_LICENSE COPYING
 !insertmacro MUI_PAGE_DIRECTORY
 !insertmacro MUI_PAGE_COMPONENTS
 !insertmacro MUI_PAGE_INSTFILES
@@ -119,17 +125,17 @@ InstallDirRegKey HKLM "Software\\{program_name}" "Install_Dir"
 
 ; License data
 ; Not exactly translated, but it shows what's needed
-LicenseLangString myLicenseData ${{LANG_ENGLISH}} "LICENSE.txt"
-LicenseLangString myLicenseData ${{LANG_DUTCH}} "LICENSE.txt"
-;LicenseLangString myLicenseData ${{LANG_FRENCH}} "LICENSE.txt"
-LicenseLangString myLicenseData ${{LANG_GERMAN}} "LICENSE.txt"
-;LicenseLangString myLicenseData ${{LANG_KOREAN}} "LICENSE.txt"
-LicenseLangString myLicenseData ${{LANG_RUSSIAN}} "LICENSE.txt"
-LicenseLangString myLicenseData ${{LANG_SPANISH}} "LICENSE.txt"
-LicenseLangString myLicenseData ${{LANG_SWEDISH}} "LICENSE.txt"
-;LicenseLangString myLicenseData ${{LANG_TRADCHINESE}} "LICENSE.txt"
-;LicenseLangString myLicenseData ${{LANG_SIMPCHINESE}} "LICENSE.txt"
-;LicenseLangString myLicenseData ${{LANG_SLOVAK}} "LICENSE.txt"
+LicenseLangString myLicenseData ${{LANG_ENGLISH}} "COPYING"
+LicenseLangString myLicenseData ${{LANG_DUTCH}} "COPYING"
+;LicenseLangString myLicenseData ${{LANG_FRENCH}} "COPYING"
+LicenseLangString myLicenseData ${{LANG_GERMAN}} "COPYING"
+;LicenseLangString myLicenseData ${{LANG_KOREAN}} "COPYING"
+LicenseLangString myLicenseData ${{LANG_RUSSIAN}} "COPYING"
+LicenseLangString myLicenseData ${{LANG_SPANISH}} "COPYING"
+LicenseLangString myLicenseData ${{LANG_SWEDISH}} "COPYING"
+;LicenseLangString myLicenseData ${{LANG_TRADCHINESE}} "COPYING"
+;LicenseLangString myLicenseData ${{LANG_SIMPCHINESE}} "COPYING"
+;LicenseLangString myLicenseData ${{LANG_SLOVAK}} "COPYING"
 
 LicenseData $(myLicenseData)
 
@@ -244,16 +250,27 @@ Section "{program_name} ($REQUIRED)"
   SectionIn RO
   ; Set output path to the installation directory.
   SetOutPath "$INSTDIR"
-  File /r /x .svn /x .git "${{py2exeOutputDirectory}}\\*.*"
+  ; Empty $INSTDIR before writing new files to it.
+  RmDir /r "$INSTDIR\\*.*"
+  ; Install new files...
+  File /r /x .svn /x .git "${{distOutputDirectory}}\\*.*"
 
   ; Write the installation path into the registry
   WriteRegStr HKLM SOFTWARE\\{program_name} "Install_Dir" "$INSTDIR"
 
   ; Write the uninstall keys for Windows
-  WriteRegStr HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "DisplayName" "{program_name}"
-  WriteRegStr HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "UninstallString" '"$INSTDIR\\uninstall.exe"'
-  WriteRegDWORD HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "NoModify" 1
-  WriteRegDWORD HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "NoRepair" 1
+  
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "InstallLocation"      "$INSTDIR"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "UninstallString"      "$INSTDIR\\uninstall.exe"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "DisplayIcon"          "$INSTDIR\\{icon_location}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "DisplayName"          "{uninstall_name}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "DisplayVersion"       "${{VERSION}}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "Publisher"            "{publisher}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "HelpLink"             "{url}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "URLInfoAbout"         "{url}"
+  WriteRegStr HKLM ${{UNINSTALL_REGKEY}}   "URLUpdateInfo"        "{url}"
+  WriteRegDWORD HKLM ${{UNINSTALL_REGKEY}} "NoModify" 1
+  WriteRegDWORD HKLM ${{UNINSTALL_REGKEY}} "NoRepair" 1
   WriteUninstaller "uninstall.exe"
 
 SectionEnd
@@ -261,6 +278,7 @@ SectionEnd
 ; Optional section (can be disabled by the user)
 Section "$STARTMENU_LINKS"
 
+  SetOutPath "$INSTDIR"
   CreateDirectory "$SMPROGRAMS\\{program_name}"
   CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
   CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name} ($WITHOUT_PULSEAUDIO).lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
@@ -274,10 +292,19 @@ SectionEnd
 ; Optional section (can be disabled by the user)
 Section "$DESKTOP_LINKS"
 
+  SetOutPath "$INSTDIR"
   CreateShortCut "$DESKTOP\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
 
 SectionEnd
 
+; Hidden section, always enabled
+Section -EstimatedSize
+  SectionIn RO
+  ${{GetSize}} "$INSTDIR" "/S=0K" $0 $1 $2
+  IntFmt $0 "0x%08X" $0
+  WriteRegDWORD HKLM ${{UNINSTALL_REGKEY}} "EstimatedSize" "$0"
+SectionEnd
+
 ;--------------------------------
 
 ; Uninstaller
@@ -285,7 +312,7 @@ SectionEnd
 Section "Uninstall"
 
   ; Remove registry keys
-  DeleteRegKey HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}"
+  DeleteRegKey HKLM ${{UNINSTALL_REGKEY}}
   DeleteRegKey HKLM SOFTWARE\\{program_name}
 
   ; Remove files and uninstaller
