@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,30 +20,16 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-    #print 'USING wxPython 2.9'
-
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-    #print 'USING wxPython 2.8'
-
-except: pass
-
 import os
+import re
 
 # Python X2Go
 import x2go
 import gevent
-import gevent.monkey
-gevent.monkey.patch_all()
 
 import wx
 
+import types
 import copy
 import threading
 import locale
@@ -51,6 +37,7 @@ import locale
 # PyHoca-GUI modules
 import about
 import logon
+import brokerlogon
 import passphrase
 import taskbar
 import profilemanager
@@ -64,7 +51,6 @@ import listdesktops
 import serverinfo
 
 wx.SetDefaultPyEncoding("utf-8")
-wx.InitAllImageHandlers()
 
 #def SetExitHandler(func):
 #    """\
@@ -117,8 +103,8 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
     wxPython and gevent.
 
     """
-    def __init__(self, args, logger, liblogger, 
-                 appname='PyHoca-GUI', 
+    def __init__(self, args, logger, liblogger,
+                 appname='PyHoca-GUI',
                  vendorname='Open Source Software Foundation',
                  version=None,):
         """\
@@ -152,6 +138,8 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
 
         self.args = args
 
+        self.gevent_sleep_when_idle = 0.25
+
         if logger is None:
             self._pyhoca_logger = x2go.X2GoLogger(tag=self.appname)
         else:
@@ -212,6 +200,30 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
         if x2go.X2GOCLIENT_OS == 'Windows' and self.args.start_pulseaudio and os.environ.has_key('PYHOCAGUI_DEVELOPMENT') and os.environ['PYHOCAGUI_DEVELOPMENT'] == '1':
             _x2goclient_kwargs['pulseaudio_installdir'] = os.path.dirname(basepath.pulseaudio_binary)
 
+        self.broker_autoconnect = self.args.broker_autoconnect
+        if self.args.broker_url:
+            _x2goclient_kwargs['broker_url'] = self.args.broker_url
+            if not re.match('^(http://|https://|ssh://).*', self.args.broker_url):
+                self.broker_autoconnect = True
+            else:
+                if not re.match('(http|ssh)', self.args.broker_url.lower()):
+                    # fall back broker mode... -> HTTP (and trigger querying for the exact URL)
+                    _x2goclient_kwargs['broker_url'] = 'HTTP'
+            self.with_brokerage = True
+        else:
+            self.with_brokerage = False
+
+        if self.args.broker_password:
+            _x2goclient_kwargs['broker_password'] = self.args.broker_password
+
+        if self.args.broker_name:
+            self.broker_name = self.args.broker_name
+
+        if self.args.broker_cacertfile is not None:
+            self.broker_cacertfile = os.path.expanduser(self.args.broker_cacertfile)
+            if self.broker_cacertfile and os.path.exists(self.broker_cacertfile):
+                os.environ['REQUESTS_CA_BUNDLE'] = self.broker_cacertfile
+
         try:
             if self.args.logon_window_position:
                 self.logon_window_position_x = int(self.args.logon_window_position.split('x')[0])
@@ -224,11 +236,10 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
         x2go.X2GoClient.__init__(self, **_x2goclient_kwargs)
 
         wx.App.__init__(self, redirect=False, clearSigInt=False)
-
         #SetExitHandler(self._exit_handler)
 
         if not self.args.disable_splash:
-            splash.PyHocaGUI_SplashScreen(splash_image=self.args.splash_image)
+            splash.PyHocaGUI_SplashScreen(self, splash_image=self.args.splash_image)
 
         self.Bind(wx.EVT_IDLE, self.OnIdle)
 
@@ -261,7 +272,7 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
 
         """
         try:
-            gevent.sleep(.04)
+            gevent.sleep(self.gevent_sleep_when_idle)
         except KeyboardInterrupt:
             self._pyhoca_logger('Received Ctrl-C keyboard interrupt... Wait till %s has exited cleanly.' % self.appname, loglevel=x2go.loglevel_NOTICE)
             self.WakeUpIdle()
@@ -303,7 +314,7 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             self.about = about.PyHocaGUI_AboutFrame(self, about_image=self.args.about_image)
         self.about.Show(False)
 
-        self.about_pythonx2go = about.PyHocaGUI_AboutFrame(self, about_image='pythonx2go-about-logo.png', about_what="Python X2Go")
+        self.about_pythonx2go = about.PyHocaGUI_AboutFrame(self, about_image='Python-X2Go_about-logo.png', about_what="Python X2Go")
         self.about_pythonx2go.Show(False)
 
         self.taskbar = taskbar.PyHocaGUI_TaskBarIcon(self.about)
@@ -350,15 +361,20 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
                 if not self.args.single_session_profile:
                     self.auto_connect = True
                 self._pyhoca_logger('opening default session profile %s' % profile_name, loglevel=x2go.log.loglevel_NOTICE)
-                self._X2GoClient__register_session(profile_name=profile_name, auto_connect=self.auto_connect)
+                try:
+                    self._X2GoClient__register_session(profile_name=profile_name, auto_connect=self.auto_connect)
+                except x2go.x2go_exceptions.X2GoBrokerConnectionException:
+                    self.session_registration_failed(profile_name=profile_name)
 
-        if self.auto_connect:
+        if self.auto_connect or self.broker_autoconnect:
             gevent.spawn(self._auto_connect)
 
     def _auto_connect(self):
         """\
         Register all available session profiles on application start.
 
+        If brokerage is used, handle auto connecting to the broker before that, as well.
+
         The auto-registration of all session profiles will trigger the auto-connect feature
         implemented in C{X2GoClient} of Python X2Go.
 
@@ -366,7 +382,12 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
         # wait for splash to appear
         if not self.args.disable_splash:
             gevent.sleep(1)
-        if not self.args.session_profile:
+
+        # auto connect to the broker if requested
+        if self.with_brokerage and self.broker_autoconnect:
+            self.OnBrokerAuthenticate(None)
+
+        if self.auto_connect and not self.args.session_profile:
             self._X2GoClient__register_all_session_profiles()
 
     def session_auto_connect(self, session_uuid, **kwargs):
@@ -791,7 +812,10 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             return
         self.taskbar.SetIconConnecting(profile_name)
         if session_uuid is None:
-            session_uuid = self._X2GoClient__register_session(profile_name=profile_name)
+            try:
+                session_uuid = self._X2GoClient__register_session(profile_name=profile_name)
+            except x2go.x2go_exceptions.X2GoBrokerConnectionException:
+                self.session_registration_failed(profile_name)
         if session_uuid:
             self._temp_disabled_profile_names.append(profile_name)
             gevent.spawn(self._do_authenticate, evt, session_uuid)
@@ -800,6 +824,36 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             if not self.is_session_profile(profile_name):
                 profilemanager.PyHocaGUI_ProfileManager(self, 'ADD_EXPLICITLY', profile_name=profile_name)
 
+    def OnBrokerAuthenticate(self, evt):
+        """\
+        Gets called if the user requests connecting to a session profile.
+
+        @param evt: event
+        @type evt: C{obj}
+
+        """
+        brokerlogon.PyHocaGUI_BrokerDialogBoxPassword(self, caller=self)
+
+    def OnBrokerDisconnect(self, evt):
+        """\
+        Reset (disconnect from) the broker connection.
+
+        @param evt: event
+        @type evt: C{obj}
+
+        """
+        self._hide_notifications_map = {}
+        self._temp_launching_pubapp_profiles = []
+        self._temp_launching_pubapp_locks = {}
+        self._temp_disabled_profile_names = []
+        self._temp_disabled_session_names = {}
+        self._remember_shared_folders = {}
+
+        for profile_name in self._X2GoClient__client_connected_profiles(return_profile_names=True):
+            self._X2GoClient__disconnect_profile(profile_name)
+
+        self.session_profiles.broker_disconnect()
+
     def OnSessionStart(self, evt):
         """\
         Gets called if the user requests to start a new X2Go session.
@@ -1511,7 +1565,7 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
         else:
             m.Show()
             while m in self._sub_windows:
-                gevent.sleep(.04)
+                gevent.sleep(.2)
 
         retval = m.Yes()
         m.Destroy()
@@ -1590,6 +1644,19 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             self.WakeUpIdle()
             self.ExitMainLoop()
 
+    def session_registration_failed(self, profile_name='UNKNOWN', **kwargs):
+        """\
+        Notify about session registration failures.
+
+        @param profile_name: profile name of session that called this hook method
+        @type profile_name: C{str}
+
+        """
+        self.notifier.send(_(u'%s - session failure') % profile_name, _(u'The session initialization failed.'), icon='session_error', timeout=10000)
+        if self.exit_on_disconnect:
+            self.WakeUpIdle()
+            self.ExitMainLoop()
+
     def HOOK_desktop_sharing_denied(self, profile_name='UNKNOWN', **kwargs):
         """\
         Notify about the denial of desktop sharing by the other user.
@@ -1665,7 +1732,7 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             self.WakeUpIdle()
             self.ExitMainLoop()
 
-    def HOOK_forwarding_tunnel_setup_failed(self, profile_name='UNKNOWN', session_name='UNKNOWN', chain_host='UNKNOWN', chain_port=0, **kwargs):
+    def HOOK_forwarding_tunnel_setup_failed(self, profile_name='UNKNOWN', session_name='UNKNOWN', chain_host='UNKNOWN', chain_port=0, subsystem=None, **kwargs):
         """\
         Notify about port forwarding tunnel setup failures.
 
@@ -1677,9 +1744,16 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
         @type chain_host: C{str}
         @param chain_port: port of chain host (forwarding tunnel end point)
         @type chain_port: C{str}
+        @param subsystem: information on the subsystem that provoked this hook call
+        @type subsystem: C{str}
 
         """
-        self.notifier.send(_(u'%s - session failure') % profile_name, _(u'Forwarding tunnel request to [%s]:%s for session %s was denied by remote X2Go/SSH server. Session startup failed.') % (chain_host, chain_port, session_name), icon='session_error', timeout=10000)
+        if type(subsystem) in (types.StringType, types.UnicodeType):
+            _subsystem = '(%s) ' % subsystem
+        else:
+            _subsystem = ''
+
+        self.notifier.send(_(u'%s - session failure') % profile_name, _(u'Forwarding tunnel request to [%s]:%s for session %s was denied by remote X2Go/SSH server. Subsystem %sstartup failed.') % (chain_host, chain_port, session_name, _subsystem), icon='session_error', timeout=10000)
         if not self._hide_notifications_map.has_key(profile_name):
             self._hide_notifications_map[profile_name] = []
         self._hide_notifications_map[profile_name].append(session_name)
@@ -1923,3 +1997,32 @@ class PyHocaGUI(wx.App, x2go.X2GoClient):
             evt.SetId(_dummy_id)
             self.OnServerDisconnect(evt)
 
+    def HOOK_broker_ignore_connection_problems(self, profile_name='UNKNOWN', is_profile_connected=False, **kwargs):
+        """\
+        Query about what to do with broker connection failures.
+
+        @param profile_name: profile name of a session that triggered this hook method
+        @type profile_name: C{str}
+        @param is_profile_connected: C{True} if the given session profile is already conneced to the server
+        @type is_profile_connected: C{bool}
+
+        @return: C{true} if session startup shall be attempted anyway, even if session
+            broker is down.
+        @rtype: C{bool}
+
+        """
+        if is_profile_connected:
+            m = messages.PyHoca_MessageWindow_OkCancel(self,
+                                                       title=_(u'%s: connection failure') % self.broker_name,
+                                                       msg=_(u"While initializing a session for profile '%s' the connection\nto %s has failed.\n\nIt is possible to attempt session initialization anyway. Do you\nwant to continue?") % (profile_name, self.broker_name),
+                                                       icon='warning',
+                                                       profile_name=profile_name)
+        else:
+            m = messages.PyHoca_MessageWindow_OkCancel(self,
+                                                       title=_(u'%s: connection failure') % self.broker_name,
+                                                       msg=_(u"While connecting to profile '%s' the connection\nto %s has failed.\n\nIt is possible to attempt session initialization anyway. Do you\nwant to continue?") % (profile_name, self.broker_name),
+                                                       icon='warning',
+                                                       profile_name=profile_name)
+
+        m.ShowModal()
+        return m.Ok()
