@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,24 +20,9 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 # Python X2Go
 import x2go
 
-# gevent
-import gevent
-import gevent.monkey
-gevent.monkey.patch_all()
-
 import wx
 import os
 
@@ -54,7 +39,7 @@ class PyHocaGUI_DialogBoxListDesktops(wx.Dialog):
     Dialog box for selection from a list of sharable desktops.
 
     """
-    def __init__(self, _PyHocaGUI, profile_name): 
+    def __init__(self, _PyHocaGUI, profile_name):
         """\
         Desktop list and selection dialog box (constructor).
 
@@ -80,7 +65,7 @@ class PyHocaGUI_DialogBoxListDesktops(wx.Dialog):
 
         self.SetTitle(_(u'Share Desktop Session - %s') % profile_name)
 
-        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Select one of the available desktop sessions on this server')+':', size=(-1, -1)) 
+        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Select one of the available desktop sessions on this server')+':', size=(-1, -1))
         self.desktopList = wx.ListCtrl(self, size=(420,140),
                                        style=wx.LC_REPORT|wx.BORDER_SUNKEN|wx.LC_SINGLE_SEL)
         self.desktopList.InsertColumn(0, 'Display')
@@ -116,13 +101,13 @@ class PyHocaGUI_DialogBoxListDesktops(wx.Dialog):
         modeSizer.Add(self.shareMode0, 0, wx.ALL, 5)
         modeSizer.Add(self.shareMode1, 0, wx.ALL, 5)
 
-        btnSizer.Add(self.okBtn, 0, wx.ALL, 5) 
-        btnSizer.Add(self.refreshBtn, 0, wx.ALL, 5) 
-        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5) 
+        btnSizer.Add(self.okBtn, 0, wx.ALL, 5)
+        btnSizer.Add(self.refreshBtn, 0, wx.ALL, 5)
+        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5)
 
-        mainSizer.Add(titleSizer, 0, wx.ALL, 5) 
-        mainSizer.Add(listSizer, 0, wx.ALL|wx.EXPAND, 5) 
-        mainSizer.Add(modeSizer, 0, wx.ALL, 5) 
+        mainSizer.Add(titleSizer, 0, wx.ALL, 5)
+        mainSizer.Add(listSizer, 0, wx.ALL|wx.EXPAND, 5)
+        mainSizer.Add(modeSizer, 0, wx.ALL, 5)
         mainSizer.Add(btnSizer, 0, wx.ALL|wx.ALIGN_RIGHT, 5)
 
         self.SetSizerAndFit(mainSizer)
