@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,23 +20,11 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 # Python X2Go
 import x2go
 
 # gevent
 import gevent
-import gevent.monkey
-gevent.monkey.patch_all()
 
 import wx
 import os
@@ -54,7 +42,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
     Logon window for L{PyHocaGUI}.
 
     """
-    def __init__(self, _PyHocaGUI, profile_name, caller=None, passphrase=None, sshproxy_passphrase=None, sshproxy_auth=False, twofactor_auth=False, sshproxy_twofactor_auth=False): 
+    def __init__(self, _PyHocaGUI, profile_name, caller=None, passphrase=None, sshproxy_passphrase=None, sshproxy_auth=False, twofactor_auth=False, sshproxy_twofactor_auth=False):
         """\
         Logon window (constructor)
 
@@ -73,6 +61,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
 
         """
         self._PyHocaGUI = _PyHocaGUI
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.1
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self._pyhoca_logger('password dialog box started', loglevel=x2go.loglevel_INFO, )
 
@@ -95,22 +84,22 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
         self.passphrase = passphrase
         self.sshproxy_passphrase = sshproxy_passphrase
 
-        self.userLbl = wx.StaticText(self, wx.ID_ANY, _(u'Username')+':', size=(-1, -1)) 
-        self.userTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1)) 
-        self.passwordLbl = wx.StaticText(self, wx.ID_ANY, _(u'Password')+':', size=(-1, -1)) 
-        self.passwordTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1)) 
+        self.userLbl = wx.StaticText(self, wx.ID_ANY, _(u'Username')+':', size=(-1, -1))
+        self.userTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1))
+        self.passwordLbl = wx.StaticText(self, wx.ID_ANY, _(u'Password')+':', size=(-1, -1))
+        self.passwordTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1))
         self.passwordTxt.SetFocus()
         self.loginBtn = wx.Button(self, wx.ID_OK, _(u'Authenticate'), )
         self.loginBtn.SetDefault()
 
         _tab_order = []
 
-        # widgets 
+        # widgets
         if self.sshproxy_auth:
-            self.sshProxyUserLbl = wx.StaticText(self, wx.ID_ANY, _(u'Username')+':', size=(-1, -1)) 
-            self.sshProxyUserTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1)) 
-            self.sshProxyPasswordLbl = wx.StaticText(self, wx.ID_ANY, _(u'Password')+':', size=(-1, -1)) 
-            self.sshProxyPasswordTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1)) 
+            self.sshProxyUserLbl = wx.StaticText(self, wx.ID_ANY, _(u'Username')+':', size=(-1, -1))
+            self.sshProxyUserTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1))
+            self.sshProxyPasswordLbl = wx.StaticText(self, wx.ID_ANY, _(u'Password')+':', size=(-1, -1))
+            self.sshProxyPasswordTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1))
             self.sshProxyPasswordTxt.SetFocus()
             self.sshProxyLoginBtn = wx.Button(self, wx.ID_OK, '  '+_(u'Start SSH tunnel')+'  ')
             self.sshProxyLoginBtn.SetDefault()
@@ -151,7 +140,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             credSizer = wx.GridBagSizer(hgap=2, vgap=2)
         mainSizer = wx.BoxSizer(wx.VERTICAL)
 
-        # sizer / layout 
+        # sizer / layout
         if self.sshproxy_auth:
 
             credSizer = wx.GridBagSizer(hgap=4, vgap=2)
@@ -162,37 +151,37 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             credSizer.Add(self.sshProxyUserLbl, pos=(1,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
             credSizer.Add(self.sshProxyUserTxt, pos=(1,1), flag=wx.ALL, border=5)
 
-            credSizer.Add(self.userLbl, pos=(1,2), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5) 
-            credSizer.Add(self.userTxt, pos=(1,3), flag=wx.ALL, border=5) 
+            credSizer.Add(self.userLbl, pos=(1,2), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
+            credSizer.Add(self.userTxt, pos=(1,3), flag=wx.ALL, border=5)
 
         else:
-            credSizer.Add(self.userLbl, pos=(0,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5) 
-            credSizer.Add(self.userTxt, pos=(0,1), flag=wx.ALL, border=5) 
+            credSizer.Add(self.userLbl, pos=(0,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
+            credSizer.Add(self.userTxt, pos=(0,1), flag=wx.ALL, border=5)
 
         if self.sshproxy_auth:
 
             credSizer.Add(self.sshProxyPasswordLbl, pos=(2,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
             credSizer.Add(self.sshProxyPasswordTxt, pos=(2,1), flag=wx.ALL, border=5)
 
-            credSizer.Add(self.passwordLbl, pos=(2,2), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5) 
+            credSizer.Add(self.passwordLbl, pos=(2,2), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
             credSizer.Add(self.passwordTxt, pos=(2,3), flag=wx.ALL, border=5)
 
         else:
-            credSizer.Add(self.passwordLbl, pos=(1,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5) 
+            credSizer.Add(self.passwordLbl, pos=(1,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
             credSizer.Add(self.passwordTxt, pos=(1,1), flag=wx.ALL, border=5)
 
         if self.sshproxy_auth:
             btnSizer.Add(self.sshProxyLoginBtn, 0, wx.ALL, 5)
-        btnSizer.Add(self.loginBtn, 0, wx.ALL, 5) 
-        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5) 
+        btnSizer.Add(self.loginBtn, 0, wx.ALL, 5)
+        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5)
 
-        mainSizer.Add(credSizer, 0, wx.ALL, 5) 
+        mainSizer.Add(credSizer, 0, wx.ALL, 5)
         mainSizer.Add(btnSizer, 0, wx.ALL|wx.ALIGN_RIGHT, 5)
 
         if self.current_profile_config.has_key('user'):
             self.userTxt.SetValue(self.current_profile_config['user'])
-        else:
-            self.userTxt.SetValue(self._PyHocaGUI.args.username)
+            if not self.current_profile_config['user'] and not self.sshproxy_auth:
+                self.userTxt.SetFocus()
 
         if self.sshproxy_auth:
 
@@ -203,10 +192,10 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
                 if self.current_profile_config.has_key('sshproxysameuser') and self.current_profile_config['sshproxysameuser']:
                     self.sshProxyUserTxt.SetValue(self.current_profile_config['user'])
 
-        # Logged in variable 
+        # Logged in variable
         self.loggedIn = False
 
-        self.SetSizerAndFit(mainSizer) 
+        self.SetSizerAndFit(mainSizer)
         self.Layout()
 
         for i in xrange(len(_tab_order) - 1):
@@ -285,7 +274,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             force_password_auth = False
             sshproxy_force_password_auth = True
         else:
-            force_password_auth = True 
+            force_password_auth = True
             sshproxy_force_password_auth = True
 
         wx.BeginBusyCursor()
@@ -309,7 +298,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
                                                  icon='auth_error')
                 self._PyHocaGUI.OnServerDisconnect(evt)
             else:
-                self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
+                self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
                                                  title=_(u'%s - connect') % self.current_profile_name,
                                                  text=_(u'Authentication has been successful.'),
                                                  icon='auth_success')
@@ -356,8 +345,8 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
                 self.sshProxyLoginBtn.SetLabel(_(u'SSH tunnel started'))
                 return
             else:
-                self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-                                                 title=_(u'%s - connect failure') % self.current_profile_name, 
+                self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+                                                 title=_(u'%s - connect failure') % self.current_profile_name,
                                                  text=_(u'Authentication failed!'),
                                                  icon='auth_failed')
                 connect_failed = True
@@ -366,7 +355,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             try: wx.EndBusyCursor()
             except: pass
             self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
-                                             title=_(u'%s - SSH proxy') % self.current_profile_name, 
+                                             title=_(u'%s - SSH proxy') % self.current_profile_name,
                                              text=_(u'Authentication to the SSH proxy server failed!'),
                                              icon='auth_failed')
 
@@ -386,24 +375,24 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
                 connect_failed = True
 
         #except gevent.dns.DNSError, e:
-        #    self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-        #                                     title=_(u'%s - DNS error') % self.current_profile_name, 
+        #    self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+        #                                     title=_(u'%s - DNS error') % self.current_profile_name,
         #                                     text=e.strerror + '!',
         #                                     icon='auth_error')
         #    connect_failed = True
 
         except gevent.socket.error, e:
-            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-                                             title=_(u'%s - socket error') % self.current_profile_name, 
+            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+                                             title=_(u'%s - socket error') % self.current_profile_name,
                                              text=e.strerror + '!',
                                              icon='auth_error')
             connect_failed = True
 
         except x2go.X2GoHostKeyException, e:
-            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-                                             title=_(u'%s - host key error') % self.current_profile_name, 
+            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+                                             title=_(u'%s - host key error') % self.current_profile_name,
                                              text=_(u'The remote server\'s host key is invalid or has not been accepted by the user') + '!',
-                                             icon='auth_error', 
+                                             icon='auth_error',
                                              timeout=4000)
             connect_failed = True
 
@@ -471,8 +460,8 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             connect_failed = True
 
         except:
-            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-                                             title=_(u'%s - unknown error') % self.current_profile_name, 
+            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+                                             title=_(u'%s - unknown error') % self.current_profile_name,
                                              text=_(u'An unknown error occured during authentication!'),
                                              icon='auth_error')
             connect_failed = True
@@ -514,6 +503,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
         Tidy up some stuff in the main application instance when the logon window gets destroyed.
 
         """
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.25
         try:
             self._PyHocaGUI._sub_windows.remove(self)
         except ValueError:
