@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,19 +18,8 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 import os.path
 import wx
-import re
 import StringIO
 import base64
 
@@ -38,7 +27,6 @@ import x2go.defaults
 import x2go.x2go_exceptions
 
 import basepath
-_icons_location = basepath.icons_basepath
 
 class PyHocaGUI_Menu_TaskbarManageProfile(wx.Menu):
     """\
@@ -73,18 +61,27 @@ class PyHocaGUI_Menu_TaskbarManageProfile(wx.Menu):
             self._PyHocaGUI._eventid_profilenames_map[ID_EXPORTPROFILE] = \
             self._PyHocaGUI._eventid_profilenames_map[ID_DELETEPROFILE] = profile_name
 
-        self.Append(text=_(u"Edit Profile"), id=ID_EDITPROFILE)
-        if not self._PyHocaGUI.args.single_session_profile:
-            self.AppendSeparator()
-            self.Append(text=_(u"Use as Template for New Profile"), id=ID_COPYPROFILE)
-            self.AppendSeparator()
-            self.Append(text=_(u"Export Profile"), id=ID_EXPORTPROFILE)
-            self.Append(text=_(u"Delete Profile"), id=ID_DELETEPROFILE)
-
+        if self._PyHocaGUI.session_profiles.is_mutable(profile_name):
+            self.Append(text=_(u"Edit Profile"), id=ID_EDITPROFILE)
+        else:
+            self.Append(text=_(u"View Profile"), id=ID_EDITPROFILE)
         self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileEdit, id=ID_EDITPROFILE)
-        self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileCopy, id=ID_COPYPROFILE)
-        self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileExport, id=ID_EXPORTPROFILE)
-        self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileDelete, id=ID_DELETEPROFILE)
+
+        if not self._PyHocaGUI.args.single_session_profile:
+
+            self.AppendSeparator()
+
+            if self._PyHocaGUI.session_profiles.is_mutable(profile_name):
+                self.Append(text=_(u"Use as Template for New Profile"), id=ID_COPYPROFILE)
+                self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileCopy, id=ID_COPYPROFILE)
+                self.AppendSeparator()
+
+            self.Append(text=_(u"Export Profile"), id=ID_EXPORTPROFILE)
+            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileExport, id=ID_EXPORTPROFILE)
+
+            if self._PyHocaGUI.session_profiles.is_mutable(profile_name):
+                self.Append(text=_(u"Delete Profile"), id=ID_DELETEPROFILE)
+                self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileDelete, id=ID_DELETEPROFILE)
 
 
 class PyHocaGUI_Menu_TaskbarOptionsManager(wx.Menu):
@@ -121,8 +118,8 @@ class PyHocaGUI_Menu_TaskbarOptionsManager(wx.Menu):
             if not self._PyHocaGUI.args.single_session_profile:
 
                 ID_PROFILEMANAGER = wx.NewId()
-                _maintain_profiles_item = self.AppendMenu(id=ID_PROFILEMANAGER, 
-                                                          text=_(u"Profile Manager"), 
+                _maintain_profiles_item = self.AppendMenu(id=ID_PROFILEMANAGER,
+                                                          text=_(u"Profile Manager"),
                                                           submenu=PyHocaGUI_Menu_TaskbarProfileNames(self._PyHocaGUI,
                                                                                                      caller=self,
                                                                                                      filter_profiles=[],
@@ -134,7 +131,9 @@ class PyHocaGUI_Menu_TaskbarOptionsManager(wx.Menu):
                 if self._PyHocaGUI.profilemanager_disabled:
                     _maintain_profiles_item.Enable(False)
 
-            else:
+                self.AppendSeparator()
+
+            elif self._PyHocaGUI.session_profiles.has_profile_name(self._PyHocaGUI.args.session_profile):
                 ID_SINGLEPROFILEMANAGER = wx.NewId()
                 _maintain_profile_item = self.AppendMenu(id=ID_SINGLEPROFILEMANAGER,
                                                          text=_(u'Manage Session Profile'),
@@ -142,14 +141,21 @@ class PyHocaGUI_Menu_TaskbarOptionsManager(wx.Menu):
                                                         )
                 if self._PyHocaGUI.args.session_profile in self._PyHocaGUI.client_connected_profiles(return_profile_names=True):
                     _maintain_profile_item.Enable(False)
+                self.AppendSeparator()
 
+        if self._PyHocaGUI.with_brokerage and self._PyHocaGUI.session_profiles.is_broker_authenticated():
+            ID_BROKER_DISCONNECT = wx.NewId()
+            self.Append(id=ID_BROKER_DISCONNECT, text=_(u"Disconnect from session broker"))
+            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnBrokerDisconnect, id=ID_BROKER_DISCONNECT)
             self.AppendSeparator()
 
-            ID_PRINTINGPREFS = wx.NewId()
-            _printingprefs_item = self.Append(id=ID_PRINTINGPREFS, text=_(u"Printing Preferences"))
-            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnPrintingPreferences, id=ID_PRINTINGPREFS)
-            if self._PyHocaGUI.printingprefs_disabled:
-                _printingprefs_item.Enable(False)
+        ID_PRINTINGPREFS = wx.NewId()
+        _printingprefs_item = self.Append(id=ID_PRINTINGPREFS, text=_(u"Printing Preferences"))
+        self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnPrintingPreferences, id=ID_PRINTINGPREFS)
+        if self._PyHocaGUI.printingprefs_disabled:
+            _printingprefs_item.Enable(False)
+
+        if not self._PyHocaGUI.restricted_trayicon:
 
             ID_OPTIONS = wx.NewId()
             _options_item = self.Append(id=ID_OPTIONS, text=_(u"Client Options"))
@@ -243,7 +249,7 @@ class PyHocaGUI_Menu_TaskbarSessionActions(wx.Menu):
                 _rs = self.Append(text=_(u"Resume Session (not possible)"), id=ID_RESUMESESSION_DISABLED)
                 _rs.Enable(False)
 
-            if session_info is not None and session_info.is_published_applications_provider() and not self._PyHocaGUI.get_profile_config(profile_name)['published']:
+            if session_info is not None and session_info.is_published_applications_provider() and not self._PyHocaGUI.get_profile_config(profile_name, 'published'):
                 _rs.Enable(False)
 
         elif _session_status == 'R':
@@ -257,14 +263,14 @@ class PyHocaGUI_Menu_TaskbarSessionActions(wx.Menu):
                     _ts.Enable(False)
 
             if not _s.is_shadow_session():
-                if self._PyHocaGUI.disconnect_on_suspend and self._PyHocaGUI.exit_on_disconnect and _s.has_terminal_session(): 
+                if self._PyHocaGUI.disconnect_on_suspend and self._PyHocaGUI.exit_on_disconnect and _s.has_terminal_session():
                     _ss = self.Append(text=_(u"Suspend Session (and disconnect/exit)"), id=ID_SUSPENDSESSION)
                 elif self._PyHocaGUI.disconnect_on_suspend and _s.has_terminal_session():
                     _ss = self.Append(text=_(u"Suspend Session (and disconnect)"), id=ID_SUSPENDSESSION)
                 else:
                     _ss = self.Append(text=_(u"Suspend Session"), id=ID_SUSPENDSESSION)
 
-                if _s.is_published_applications_provider() and not self._PyHocaGUI.get_profile_config(profile_name)['published']:
+                if _s.is_published_applications_provider() and not self._PyHocaGUI.get_profile_config(profile_name, 'published'):
                     _ss.Enable(False)
         if not _s.is_shadow_session():
             if self._PyHocaGUI.disconnect_on_terminate and self._PyHocaGUI.exit_on_disconnect and _s.has_terminal_session():
@@ -281,7 +287,7 @@ class PyHocaGUI_Menu_TaskbarSessionActions(wx.Menu):
             else:
                 self.Append(text=_(u"End Desktop Sharing"), id=ID_TERMINATESESSION)
 
-        if _s is not None and _s.is_published_applications_provider() and self._PyHocaGUI.get_profile_config(profile_name)['published']:
+        if _s is not None and _s.is_published_applications_provider() and self._PyHocaGUI.get_profile_config(profile_name, 'published'):
             self.AppendSeparator()
             self.Append(text=_(u"Refresh menu tree"), id=ID_REFRESHMENU)
 
@@ -345,6 +351,7 @@ class PyHocaGUI_Menu_TaskbarProfileSharedFolders(wx.Menu):
         _sharable_folders = _exported_folders.keys()
         _unshared_folders = [ f for f in _sharable_folders if f and f not in _shared_folders ]
 
+        self._PyHocaGUI._eventid_unshared_folders_map = {}
         if _unshared_folders:
             self.Append(id=wx.NewId(), text=_(u'Share:'))
             for _unshared_folder in _unshared_folders:
@@ -354,6 +361,7 @@ class PyHocaGUI_Menu_TaskbarProfileSharedFolders(wx.Menu):
                 self._PyHocaGUI._eventid_unshared_folders_map[ID_THISFOLDER] = _unshared_folder
                 self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnShareLocalFolder, id=ID_THISFOLDER)
 
+        self._PyHocaGUI._eventid_shared_folders_map = {}
         if _shared_folders:
             self.Append(id=wx.NewId(), text=_(u'Unshare:'))
             for _shared_folder in _shared_folders:
@@ -401,16 +409,14 @@ class PyHocaGUI_Menu_LaunchSingleApplication(wx.Menu):
 
         wx.Menu.__init__(self)
 
-        current_profile_config = self._PyHocaGUI.get_profile_config(profile_name)
-
         _available_applications = {
             'WWWBROWSER': _(u'Internet Browser'),
             'MAILCLIENT': _(u'Email Client'),
-            'OFFICE': _(u'Office'), 
-            'TERMINAL': _(u'Terminal'), 
+            'OFFICE': _(u'Office'),
+            'TERMINAL': _(u'Terminal'),
             }
 
-        for application in current_profile_config['applications']:
+        for application in self._PyHocaGUI.get_profile_config(profile_name, 'applications'):
 
             _app_id = wx.NewId()
             self._PyHocaGUI._eventid_profilenames_map[_app_id] = profile_name
@@ -450,6 +456,7 @@ def _generate_Menu_PublishedApplications(_PyHocaGUI, caller=None, profile_name=N
     else:
         _icon_size = "22x22"
 
+    _icons_location = basepath.icons_basepath
     _category_name_translator = {
         'Multimedia': (_(u'Multimedia'), os.path.normpath('%s/PyHoca/%s/applications-multimedia.png' % (_icons_location, _icon_size), ), ),
         'Development': (_(u'Development'), os.path.normpath('%s/PyHoca/%s/applications-development.png' % (_icons_location, _icon_size), ), ),
@@ -466,6 +473,7 @@ def _generate_Menu_PublishedApplications(_PyHocaGUI, caller=None, profile_name=N
 
     _PyHocaGUI._eventid_pubapp_execmap[profile_name] = {}
 
+    nolog = wx.LogNull()
     _wx_menu_map = {}
     if menu_map[_lang].keys():
         for cat in menu_map[_lang].keys():
@@ -484,17 +492,17 @@ def _generate_Menu_PublishedApplications(_PyHocaGUI, caller=None, profile_name=N
                     _menu_item.SetBitmap(wx.Bitmap(os.path.normpath('%s/PyHoca/%s/x2go-logo-grey.png' % (_icons_location, _icon_size))))
                 else:
                     _menu_entry_icon_decoded = base64.b64decode(_item['icon'])
-                    if not re.match('^<\?(xml|XML).*version=.*encoding=.*standalone=.*\?>.*', _menu_entry_icon_decoded.split('\n')[0]):
-                        _icon_image = wx.ImageFromStream(StringIO.StringIO(_menu_entry_icon_decoded))
-                        if x2go.defaults.X2GOCLIENT_OS == 'Windows':
-                            _icon_bitmap = wx.BitmapFromImage(_icon_image.Scale(16,16))
-                        else:
-                            _icon_bitmap = wx.BitmapFromImage(_icon_image.Scale(22,22))
-                        _menu_item.SetBitmap(_icon_bitmap)
+                    _icon_image = wx.ImageFromStream(StringIO.StringIO(_menu_entry_icon_decoded))
+                    if x2go.defaults.X2GOCLIENT_OS == 'Windows':
+                        _icon_bitmap = wx.BitmapFromImage(_icon_image.Scale(16,16))
+                    else:
+                        _icon_bitmap = wx.BitmapFromImage(_icon_image.Scale(22,22))
+                    _menu_item.SetBitmap(_icon_bitmap)
 
                 _wx_menu_map[_category_name_translator[cat][0]][0].AppendItem(_menu_item)
                 _PyHocaGUI.Bind(wx.EVT_MENU, _PyHocaGUI.OnPubAppExecution, id=_pubapp_id)
 
+    del nolog
     return _wx_menu_map
 
 
@@ -520,6 +528,7 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
 
         wx.Menu.__init__(self)
 
+        ID_AUTHENTICATE_BROKER=wx.NewId()
         ID_CONNECT=wx.NewId()
         ID_PUBAPPSESSIONSTART=wx.NewId()
         ID_SESSIONSTART=wx.NewId()
@@ -532,11 +541,19 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
 
         _foldersharing_disabled = False
 
-        if self._PyHocaGUI.args.single_session_profile and not self._PyHocaGUI.is_session_profile(profile_name):
+        if self._PyHocaGUI.with_brokerage and not self._PyHocaGUI.session_profiles.is_broker_authenticated():
+            _auth_menu_text = _(u'Connect to') + self._PyHocaGUI.broker_name
+            self.Append(id=ID_AUTHENTICATE_BROKER, text=_auth_menu_text)
+            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnBrokerAuthenticate, id=ID_AUTHENTICATE_BROKER)
+
+        elif self._PyHocaGUI.args.single_session_profile and not self._PyHocaGUI.is_session_profile(profile_name):
             connect = self.Append(id=ID_CONNECT, text=_(u'Connect %s') % profile_name)
             connect.Enable(False)
         else:
-            current_profile_config = self._PyHocaGUI.get_profile_config(profile_name)
+            _applications = self._PyHocaGUI.get_profile_config(profile_name, 'applications')
+            _command = self._PyHocaGUI.get_profile_config(profile_name, 'command')
+            _published = self._PyHocaGUI.get_profile_config(profile_name, 'published')
+            _useexports = self._PyHocaGUI.get_profile_config(profile_name, 'useexports')
 
             if profile_name in self._PyHocaGUI._temp_disabled_profile_names:
                 _connecting_info = self.Append(wx.NewId(), text=_(u'Currently connecting...'))
@@ -553,15 +570,15 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
                 self._PyHocaGUI._eventid_profilenames_map[ID_SESSIONSTART] = \
                     self._PyHocaGUI._eventid_profilenames_map[ID_SHADOWSESSIONSTART] = profile_name
 
-                if current_profile_config['command'] in x2go.defaults.X2GO_DESKTOPSESSIONS:
-                    self.Append(id=ID_SESSIONSTART, text='%s (%s)' % (_(u"Start &new Desktop Session"), current_profile_config['command']))
+                if _command in x2go.defaults.X2GO_DESKTOPSESSIONS:
+                    self.Append(id=ID_SESSIONSTART, text='%s (%s)' % (_(u"Start &new Desktop Session"), _command))
                     self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnSessionStart, id=ID_SESSIONSTART)
 
-                elif current_profile_config['command'] == 'SHADOW':
-                    start_shadow_session = self.Append(id=ID_SHADOWSESSIONSTART, text=_(u"Start Desktop Sharing Session"))
+                elif _command == 'SHADOW':
+                    self.Append(id=ID_SHADOWSESSIONSTART, text=_(u"Start Desktop Sharing Session"))
                     self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnShadowSessionStart, id=ID_SHADOWSESSIONSTART)
 
-                elif current_profile_config['command'] == '' and current_profile_config['published']:
+                elif _command == '' and _published:
                     _pub_app_start_item = None
                     if profile_name in self._PyHocaGUI._temp_launching_pubapp_profiles:
                         _pub_app_start_item = self.Append(id=ID_PUBAPPSESSIONSTART, text=_(u"Retrieving Application Menu..."))
@@ -570,14 +587,14 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
                         self._PyHocaGUI._eventid_profilenames_map[ID_PUBAPPSESSIONSTART] = profile_name
                         _pub_app_start_item = self.Append(id=ID_PUBAPPSESSIONSTART, text=_(u"Retrieve Application Menu"))
                         self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnPubAppSessionStart, id=ID_PUBAPPSESSIONSTART)
-                elif current_profile_config['command'] == 'RDP':
+                elif _command == 'RDP':
                     self.Append(id=ID_SESSIONSTART, text=_(u"Start &new RDP Session"))
                     self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnSessionStart, id=ID_SESSIONSTART)
                 else:
                     self.Append(id=ID_SESSIONSTART, text=_(u"Start &new Session"))
                     self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnSessionStart, id=ID_SESSIONSTART)
 
-                if current_profile_config['command'] == '' and current_profile_config['published']:
+                if _command == '' and _published:
 
                     _pubapp_sessions = [ _pas for _pas in self._PyHocaGUI.client_pubapp_sessions_of_profile_name(profile_name, return_objects=True) if _pas.is_running() ]
                     if _pubapp_sessions:
@@ -652,16 +669,16 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
                     self._PyHocaGUI._eventid_profilenames_map[ID_LAUNCHAPPLICATION] = \
                         self._PyHocaGUI._eventid_profilenames_map[ID_CLEANSESSIONS] = profile_name
 
-                    if current_profile_config['applications'] and current_profile_config['command'] in x2go.defaults.X2GO_DESKTOPSESSIONS.keys() and not current_profile_config['published']:
+                    if _applications and _command in x2go.defaults.X2GO_DESKTOPSESSIONS.keys() and not _published:
                         self.AppendSeparator()
                         self.AppendMenu(id=ID_LAUNCHAPPLICATION, text=_(u"Launch Single Application"),
                                         submenu=PyHocaGUI_Menu_LaunchSingleApplication(self._PyHocaGUI, caller=self, profile_name=profile_name)
                                        )
-                        if current_profile_config['command'] != 'SHADOW' and not self._PyHocaGUI.restricted_trayicon:
+                        if _command != 'SHADOW' and not self._PyHocaGUI.restricted_trayicon:
                             self.Append(id=ID_SHADOWSESSIONSTART, text=_(u"Start Desktop Sharing Session"))
                             self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnShadowSessionStart, id=ID_SHADOWSESSIONSTART)
 
-                    if current_profile_config['published']:
+                    if _published:
 
                         if not self._PyHocaGUI.restricted_trayicon:
                             self.AppendSeparator()
@@ -721,7 +738,7 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
                     if _session_list:
 
                         # newest sessions at the top
-                        if current_profile_config['published']:
+                        if _published:
                             _session_list_names = [ _s_name for _s_name in _session_list.keys() if not _session_list[_s_name].is_published_applications_provider() ]
                         else:
                             _session_list_names = _session_list.keys()
@@ -777,14 +794,17 @@ class PyHocaGUI_Menu_TaskbarSessionProfile(wx.Menu):
                 if not self._PyHocaGUI.restricted_trayicon:
 
                     self.AppendSeparator()
-                    self.Append(id=ID_EDITPROFILEWHILECONNECTED, text=_(u"Customize &profile"))
+                    if self._PyHocaGUI.session_profiles.is_mutable(profile_name):
+                        self.Append(id=ID_EDITPROFILEWHILECONNECTED, text=_(u"Customize &profile"))
+                    else:
+                        self.Append(id=ID_EDITPROFILEWHILECONNECTED, text=_(u"View &profile"))
                     self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileEditWhileConnected, id=ID_EDITPROFILEWHILECONNECTED)
 
                 self._PyHocaGUI._eventid_profilenames_map[ID_EDITPROFILEWHILECONNECTED] = \
                     self._PyHocaGUI._eventid_profilenames_map[ID_SHARELOCALFOLDER] = \
                     self._PyHocaGUI._eventid_profilenames_map[ID_UNSHAREFOLDERS] = profile_name
 
-                if current_profile_config['useexports'] and \
+                if _useexports and \
                    self._PyHocaGUI._X2GoClient__profile_is_folder_sharing_available(profile_name=profile_name) and \
                    self._PyHocaGUI.get_master_session(profile_name) is not None and \
                    self._PyHocaGUI.is_session_name_enabled(profile_name, self._PyHocaGUI.get_master_session(profile_name).get_session_name()):
@@ -838,7 +858,7 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
     will be rendered in a tree-like fashion.
 
     """
-    def __init__(self, _PyHocaGUI, caller=None, 
+    def __init__(self, _PyHocaGUI, caller=None,
                  sub_profile_items=[], filter_profiles=[], disabled_profiles=[],
                  bind_method=None,
                  submenu=None,
@@ -874,7 +894,7 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
 
         wx.Menu.__init__(self)
 
-        if type(caller) == PyHocaGUI_Menu_TaskbarOptionsManager:
+        if type(caller) == PyHocaGUI_Menu_TaskbarOptionsManager and self._PyHocaGUI.session_profiles.supports_mutable_profiles():
             ID_ADDPROFILE = wx.NewId()
             self.Append(id=ID_ADDPROFILE, text=_(u"Add Profile"))
             self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileAdd, id=ID_ADDPROFILE)
@@ -896,7 +916,7 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
             for profile_name in _profile_names:
                 if len(profile_name.split('/')) >= 2:
                     _group_name = profile_name.split('/')[0]
-                    if not _group_name in _profile_groups: 
+                    if not _group_name in _profile_groups:
                         _profile_groups.append(_group_name)
 
             _profile_groups.sort()
@@ -910,7 +930,7 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
 
                 _this_id = wx.NewId()
                 self.AppendMenu(text=profile_group, id=_this_id,
-                                     submenu=PyHocaGUI_Menu_TaskbarProfileNames(self._PyHocaGUI, 
+                                     submenu=PyHocaGUI_Menu_TaskbarProfileNames(self._PyHocaGUI,
                                                                                 caller=self,
                                                                                 sub_profile_items=_sub_profile_items,
                                                                                 filter_profiles=[],
@@ -952,7 +972,10 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
                     self._PyHocaGUI.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUI, id=_this_id)
 
         if not group_name and (not _profile_groups and not _profile_names) and not filter_profiles:
-            _dummy = self.Append(text=_(u'No session profiles defined'), id=wx.NewId())
+            if self._PyHocaGUI.with_brokerage:
+                _dummy = self.Append(text=_(u'Session broker is not connected'), id=wx.NewId())
+            else:
+                _dummy = self.Append(text=_(u'No session profiles defined'), id=wx.NewId())
             _dummy.Enable(False)
 
         else:
@@ -968,7 +991,7 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
                     self.Append(text=_(u'Export Profile Group'), id=_export_id)
                 self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileExport, id=_export_id)
 
-        if bind_method is None and not group_name:
+        if bind_method is None and not group_name and self._PyHocaGUI.session_profiles.supports_mutable_profiles():
             _import_id = wx.NewId()
             self.AppendSeparator()
             self.Append(text=_(u'Import Session Profiles'), id=_import_id)
@@ -1004,18 +1027,25 @@ class PyHocaGUI_Menu_TaskbarSessionManager(wx.Menu):
 
         wx.Menu.__init__(self)
 
-        ID_AUTHENTICATE = wx.NewId()
+        ID_AUTHENTICATE_SESSION = wx.NewId()
+        ID_AUTHENTICATE_BROKER = wx.NewId()
         ID_EXIT = wx.NewId()
 
-        _auth_menu_text = _(u'Connect Server')
-        self.AppendMenu(id=ID_AUTHENTICATE, 
-                        text=_auth_menu_text, 
-                        submenu=PyHocaGUI_Menu_TaskbarProfileNames(self._PyHocaGUI, 
-                                                                   caller=self,
-                                                                   filter_profiles=[],
-                                                                   disabled_profiles=self._PyHocaGUI.client_connected_profiles(return_profile_names=True) + self._PyHocaGUI._temp_disabled_profile_names,
-                                                                   bind_method=self._PyHocaGUI.OnSessionAuthenticate))
-        self.AppendSeparator()
+        if self._PyHocaGUI.with_brokerage and not self._PyHocaGUI.session_profiles.is_broker_authenticated():
+            _auth_menu_text = _(u'Connect to') + ' ' + self._PyHocaGUI.broker_name
+            self.Append(id=ID_AUTHENTICATE_BROKER, text=_auth_menu_text)
+            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnBrokerAuthenticate, id=ID_AUTHENTICATE_BROKER)
+            self.AppendSeparator()
+        else:
+            _auth_menu_text = _(u'Connect Server')
+            self.AppendMenu(id=ID_AUTHENTICATE_SESSION,
+                            text=_auth_menu_text,
+                            submenu=PyHocaGUI_Menu_TaskbarProfileNames(self._PyHocaGUI,
+                                                                       caller=self,
+                                                                       filter_profiles=[],
+                                                                       disabled_profiles=self._PyHocaGUI.client_connected_profiles(return_profile_names=True) + self._PyHocaGUI._temp_disabled_profile_names,
+                                                                       bind_method=self._PyHocaGUI.OnSessionAuthenticate))
+            self.AppendSeparator()
 
         _profile_names = self._PyHocaGUI.session_profiles.profile_names
         _profile_names.sort()
