@@ -30,14 +30,12 @@ import basepath
 # X2Go modules
 from x2go.defaults import CURRENT_LOCAL_USER as _CURRENT_LOCAL_USER
 
-_icons_location = basepath.icons_basepath
-
 class PyHoca_MessageWindow(wx.Dialog):
     """\
     A simple message window for L{PyHocaGUI}.
 
     """
-    def __init__(self, _PyHocaGUI, parent=None, title=None, shortmsg=None, msg=None, icon=None, buttontype='ok', 
+    def __init__(self, _PyHocaGUI, parent=None, title=None, shortmsg=None, msg=None, icon=None, buttontype='ok',
                  profile_name=None,
                  session_name=None):
         """\
@@ -68,9 +66,9 @@ class PyHoca_MessageWindow(wx.Dialog):
         try: wx.EndBusyCursor()
         except: pass
 
-        self._pyhoca_messages = { 
+        self._pyhoca_messages = {
             'REALLY_DELETE_PROFILE': _(u'Are you really sure you want to\ndelete the session profile ,,%s\'\'?') % profile_name,
-            'ALREADY_RUNNING': _(u'PyHoca-GUI is already running for user ,,%s\'\'!\n\nOnly one instance of PyHoca-GUI can be started per\nuser. The PyHoca-GUI icon can be found in your desktops\'s\nnotification area/systray.') % _CURRENT_LOCAL_USER
+            'ALREADY_RUNNING': _(u'{appname} is already running for user ,,{username}\'\'!\n\nOnly one instance of {appname} can be started per\nuser. The {appname} icon can be found in your desktop\'s\nnotification area/systray.').format(appname=self._PyHocaGUI.appname, username=_CURRENT_LOCAL_USER)
         }
 
 
@@ -93,10 +91,15 @@ class PyHoca_MessageWindow(wx.Dialog):
         wx.Dialog.__init__(self, parent, wx.ID_ANY, )
         self.SetTitle('%s' % title)
 
+        _icons_location = basepath.icons_basepath
+        icon_folder = 'PyHoca'
+        if os.path.isdir(os.path.join(_icons_location, _PyHocaGUI.appname)):
+            icon_folder = _PyHocaGUI.appname
+
         if icon:
-            path_to_icon = os.path.normpath('%s/PyHoca/64x64/%s.png' % (_icons_location, icon))
+            path_to_icon = os.path.normpath('%s/%s/64x64/%s.png' % (_icons_location, icon_folder, icon))
             self.icon = wx.StaticBitmap(self, wx.ID_ANY, wx.Bitmap(path_to_icon, wx.BITMAP_TYPE_ANY))
-        self.message = wx.StaticText(self, wx.ID_ANY, self.show_message, size=(-1, -1), style=wx.ALIGN_LEFT) 
+        self.message = wx.StaticText(self, wx.ID_ANY, self.show_message, size=(-1, -1), style=wx.ALIGN_LEFT)
 
         btnSizer = wx.BoxSizer(wx.HORIZONTAL)
         msgSizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -109,8 +112,8 @@ class PyHoca_MessageWindow(wx.Dialog):
             self.Bind(wx.EVT_BUTTON, self.OnTrue, self.yesBtn)
             self.Bind(wx.EVT_BUTTON, self.OnFalse, self.noBtn)
 
-            btnSizer.Add(self.yesBtn, flag=wx.ALL, border=5) 
-            btnSizer.Add(self.noBtn, flag=wx.ALL, border=5) 
+            btnSizer.Add(self.yesBtn, flag=wx.ALL, border=5)
+            btnSizer.Add(self.noBtn, flag=wx.ALL, border=5)
 
             if buttontype == 'yesno':
                 self.yesBtn.SetDefault()
@@ -123,13 +126,13 @@ class PyHoca_MessageWindow(wx.Dialog):
 
             self.okBtn = wx.Button(self, wx.ID_ANY, _(u'Ok'),)
             self.Bind(wx.EVT_BUTTON, self.OnTrue, self.okBtn)
-            btnSizer.Add(self.okBtn, flag=wx.ALL, border=5) 
+            btnSizer.Add(self.okBtn, flag=wx.ALL, border=5)
 
         if buttontype in ('okcancel', 'cancelok'):
 
             self.cancelBtn = wx.Button(self, wx.ID_ANY, _(u'Cancel'))
             self.Bind(wx.EVT_BUTTON, self.OnFalse, self.cancelBtn)
-            btnSizer.Add(self.cancelBtn, flag=wx.ALL, borde=5) 
+            btnSizer.Add(self.cancelBtn, flag=wx.ALL, border=5)
 
         if buttontype in ('ok', 'okcancel'):
             self.okBtn.SetDefault()
@@ -145,7 +148,7 @@ class PyHoca_MessageWindow(wx.Dialog):
         mainSizer.Add(msgSizer, flag=wx.ALL, border=10)
         mainSizer.Add(btnSizer, flag=wx.ALL|wx.ALIGN_RIGHT, border=5)
 
-        self.SetSizerAndFit(mainSizer) 
+        self.SetSizerAndFit(mainSizer)
         self.Layout()
 
         maxX, maxY = wx.GetDisplaySize()
