@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,16 +20,6 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 # Python X2Go
 import x2go
 
@@ -68,6 +58,7 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
 
         """
         self._PyHocaGUI = _PyHocaGUI
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.1
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self._pyhoca_logger('SSH key passphrase dialog box started', loglevel=x2go.loglevel_INFO, )
 
@@ -91,8 +82,8 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
         else:
             keyfilenameLbl = wx.StaticText(self, wx.ID_ANY, _(u'Unlock auto-discovered SSH private key...'))
 
-        self.passphraseLbl = wx.StaticText(self, wx.ID_ANY, _(u'Passphrase')+':', size=(-1, -1)) 
-        self.passphraseTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1)) 
+        self.passphraseLbl = wx.StaticText(self, wx.ID_ANY, _(u'Passphrase')+':', size=(-1, -1))
+        self.passphraseTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(120, -1))
         self.passphraseTxt.SetFocus()
         self.unlockBtn = wx.Button(self, wx.ID_OK, _(u'Unlock SSH key'), )
         self.unlockBtn.SetDefault()
@@ -111,20 +102,20 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
         credSizer = wx.GridBagSizer(hgap=1, vgap=1)
         mainSizer = wx.BoxSizer(wx.VERTICAL)
 
-        credSizer.Add(self.passphraseLbl, pos=(0,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5) 
+        credSizer.Add(self.passphraseLbl, pos=(0,0), flag=wx.LEFT|wx.ALIGN_CENTER_VERTICAL, border=5)
         credSizer.Add(self.passphraseTxt, pos=(0,1), flag=wx.ALL, border=5)
 
-        btnSizer.Add(self.unlockBtn, 0, wx.ALL, 5) 
-        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5) 
+        btnSizer.Add(self.unlockBtn, 0, wx.ALL, 5)
+        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5)
 
         mainSizer.Add(keyfilenameLbl, 0, wx.ALL|wx.ALIGN_LEFT, 5)
-        mainSizer.Add(credSizer, 0, wx.ALL|wx.ALIGN_CENTER, 5) 
+        mainSizer.Add(credSizer, 0, wx.ALL|wx.ALIGN_CENTER, 5)
         mainSizer.Add(btnSizer, 0, wx.ALL|wx.ALIGN_RIGHT, 5)
 
-        # Logged in variable 
+        # Logged in variable
         self.loggedIn = False
 
-        self.SetSizerAndFit(mainSizer) 
+        self.SetSizerAndFit(mainSizer)
         self.Layout()
 
         for i in xrange(len(_tab_order) - 1):
@@ -259,7 +250,7 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
             self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
                                              title=_(u'%s - host key error') % self.current_profile_name,
                                              text=_(u'The remote server\'s host key is invalid or has not been accepted by the user') + '!',
-                                             icon='auth_error', 
+                                             icon='auth_error',
                                              timeout=4000)
             connect_failed = True
 
@@ -327,8 +318,8 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
                 connect_failed = True
 
         except:
-            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name, 
-                                             title=_(u'%s - unknown error') % self.current_profile_name, 
+            self._PyHocaGUI.notifier.prepare('AUTH_%s' % self.current_profile_name,
+                                             title=_(u'%s - unknown error') % self.current_profile_name,
                                              text=_(u'An unknown error occured during authentication!'),
                                              icon='auth_error')
             connect_failed = True
@@ -371,6 +362,7 @@ class PyHocaGUI_DialogBoxPassphrase(wx.Dialog):
         Tidy up some stuff in the main application instance when the logon window gets destroyed.
 
         """
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.25
         try:
             self._PyHocaGUI._sub_windows.remove(self)
         except ValueError:
