@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,6 +20,7 @@
 
 import os
 import re
+
 import wx
 
 import x2go.log as log
@@ -119,14 +120,14 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
         # widgets for print action PDFVIEW
         self.PdfViewCmdLabel = wx.StaticText(self, -1, _(u'PDF viewer command') + ':', )
         self.PdfViewCmd = wx.TextCtrl(self, -1, '', )
-        self.PdfViewCmdBrowseButton = wx.BitmapButton(self, -1, 
+        self.PdfViewCmdBrowseButton = wx.BitmapButton(self, -1,
                                                       wx.Bitmap('%s/PyHoca/16x16/system-search.png' % _icons_location, wx.BITMAP_TYPE_ANY)
                                                      )
 
         # widgets for print action PDFSAVE
         self.PdfSaveToFolderLabel = wx.StaticText(self, -1, _(u'Save PDFs to folder') + ':', )
         self.PdfSaveToFolder = wx.TextCtrl(self, -1, '', )
-        self.PdfSaveToFolderBrowseButton = wx.BitmapButton(self, -1, 
+        self.PdfSaveToFolderBrowseButton = wx.BitmapButton(self, -1,
                                                            wx.Bitmap('%s/PyHoca/16x16/system-search.png' % _icons_location, wx.BITMAP_TYPE_ANY)
                                                           )
 
@@ -406,7 +407,7 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
         wildcard = "All files (*.*)|*"
         dlg = wx.FileDialog(
             self, message=_(u"Choose PDF viewer application"), defaultDir=_LOCAL_HOME,
-            defaultFile="", wildcard=wildcard, style=wx.OPEN | wx.CHANGE_DIR )
+            defaultFile="", wildcard=wildcard, style=wx.FD_OPEN | wx.FD_CHANGE_DIR )
         # Show the dialog and retrieve the user response. If it is the OK response,
         # process the data.
         if dlg.ShowModal() == wx.ID_OK:
