@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,24 +20,9 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 # Python X2Go
 import x2go
 
-# gevent
-import gevent
-import gevent.monkey
-gevent.monkey.patch_all()
-
 import wx
 import os
 
@@ -54,7 +39,7 @@ class PyHocaGUI_DialogBoxServerInfo(wx.Dialog):
     Simple dialog box for showing server information.
 
     """
-    def __init__(self, _PyHocaGUI, profile_name): 
+    def __init__(self, _PyHocaGUI, profile_name):
         """\
         Server information dialog box (constructor).
 
@@ -75,7 +60,7 @@ class PyHocaGUI_DialogBoxServerInfo(wx.Dialog):
 
         self.SetTitle(_(u'Server Information - %s') % profile_name)
 
-        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Session Profile: %s\n\nList of X2Go Server components, add-ons and their versions...') % self.current_profile_name, size=(-1, -1)) 
+        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Session Profile: %s\n\nList of X2Go Server components, add-ons and their versions...') % self.current_profile_name, size=(-1, -1))
 
         self.infoArea = wx.TextCtrl(self, id=-1, value="", size=(520,300), style=wx.TE_READONLY|wx.TE_MULTILINE|wx.SUNKEN_BORDER)
 
