@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,24 +20,9 @@
 
 modules ={}
 
-try:
-    import wxversion
-    wxversion.select('2.9')
-except: pass
-
-try:
-    import wxversion
-    wxversion.select('2.8')
-except: pass
-
 # Python X2Go
 import x2go
 
-# gevent
-import gevent
-import gevent.monkey
-gevent.monkey.patch_all()
-
 import wx
 import os
 
@@ -54,7 +39,7 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
     Simple dialog box for selecting a session title string.
 
     """
-    def __init__(self, _PyHocaGUI, profile_name, session_name): 
+    def __init__(self, _PyHocaGUI, profile_name, session_name):
         """\
         Session title renaming dialog box (constructor).
 
@@ -67,6 +52,7 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
 
         """
         self._PyHocaGUI = _PyHocaGUI
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.1
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self._pyhoca_logger('session title query box started', loglevel=x2go.loglevel_INFO, )
 
@@ -78,8 +64,8 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
 
         self.SetTitle(_(u'Session Title - %s') % profile_name)
 
-        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Change session title to')+':', size=(-1, -1)) 
-        self.titleTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1)) 
+        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Change session title to')+':', size=(-1, -1))
+        self.titleTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(120, -1))
         self.okBtn = wx.Button(self, wx.ID_OK, _(u'OK'), )
         self.okBtn.SetDefault()
         self.cancelBtn = wx.Button(self, wx.ID_CANCEL, _(u'Cancel'), )
@@ -95,13 +81,13 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
         titleSizer.Add(self.titleLbl, 0, wx.ALL, 5)
         titleSizer.Add(self.titleTxt, 0, wx.ALL, 5)
 
-        btnSizer.Add(self.okBtn, 0, wx.ALL, 5) 
-        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5) 
+        btnSizer.Add(self.okBtn, 0, wx.ALL, 5)
+        btnSizer.Add(self.cancelBtn, 0, wx.ALL, 5)
 
-        mainSizer.Add(titleSizer, 0, wx.ALL, 5) 
+        mainSizer.Add(titleSizer, 0, wx.ALL, 5)
         mainSizer.Add(btnSizer, 0, wx.ALL|wx.ALIGN_RIGHT, 5)
 
-        self.SetSizerAndFit(mainSizer) 
+        self.SetSizerAndFit(mainSizer)
         self.Layout()
 
         maxX, maxY = wx.GetDisplaySize()
@@ -166,6 +152,7 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
         Do some PyHocaGUI specific cleanup if this window gets destroyed.
 
         """
+        self._PyHocaGUI.gevent_sleep_when_idle = 0.25
         try:
             self._PyHocaGUI._sub_windows.remove(self)
         except ValueError:
